/* fill_demo.ino

   NeopixelConnect Example for Waveshare RP2040-Zero
  -------------------------------------------------
  This is a modified version of the original example program 
  of the NeopixelConnect library written by Alan Yorinks. 
  It demonstrates the control of the built-in Neopixel LED
  on the Waveshare RP2040-Zero board using the NeopixelConnect library.
  
  
  Required library:
  - NeopixelConnect: https://github.com/AlanYorinks/NeopixelConnect

  Setup:
  - Install the NeopixelConnect library via the Arduino Library Manager.
  - Connect the Waveshare RP2040-Zero board to your computer.
  - Open this sketch in the Arduino IDE (v1.8.19 or later).
  - Select the appropriate board: Tools > Board > Arduino Mbed OS RP2040 boards > Raspberry Pi Pico
  - Select the appropriate port: Tools > Port > (your board's port).

  Tested with:
  - Arduino IDE v1.8.19
  - Arduino Mbed OS RP2040 boards v4.1.1

*/

#define MAXIMUM_NUM_NEOPIXELS 1

#include <NeoPixelConnect.h>

// Create an instance of NeoPixelConnect and initialize it
// to use GPIO pin 16 as the control pin, for a string
// of n neopixels. Name the instance p

NeoPixelConnect p(16, MAXIMUM_NUM_NEOPIXELS, pio0, 0);

void setup() {
  Serial.begin(115200);
  delay(2000);
  Serial.println("In setup");
  delay(1000);
}

void loop() {
  // set all LEDs to red
  p.neoPixelFill(255, 0, 0, true);
  Serial.print("R");
  delay(1000);
  p.neoPixelClear(true);
  delay(1000);

  // set all LEDs to green
  p.neoPixelFill(0, 255, 0, true);
  Serial.print("G");
  delay(1000);
  p.neoPixelClear(true);
  delay(1000);

  // set all LEDs to blue
  p.neoPixelFill(0, 0, 255, true);
  Serial.println("B");
  delay(1000);
  p.neoPixelClear(true);
  delay(1000);
}
