/* rtos_ledfade.ino
 * 
 * This program is a modified version of the 
 * RPi_Pico_Mbed_2thread_LED_Fade.ino example from the tutorial article titled  
 * "Program RPi Pico using Mbed library with Arduino IDE" by ralphjy on the element14 community site.
 * Link: https://community.element14.com/products/raspberry-pi/b/blog/posts/program-rpi-pico-using-mbed-library-with-arduino-ide
 * 
 * The program demonstrates the use of Mbed OS with Arduino to control 
 * two LEDs connected to a Raspberry Pi Pico.
 * It uses separate threads to fade the red and green LEDs in and out.
 * Note: The loop() function could be used as a third task, but here 
 * no activity was specified for it.
 * 
 * Hardware required:
 * - Raspberry Pi Pico
 * - Red LED connected to GPIO pin 1
 * - Green LED connected to GPIO pin 9
 * 
 * The program was tested with Arduino IDE v1.8.19 and Arduino Mbed OS RP2040 boards v4.1.1 extension.
 */
#include "rtos.h"

#define RED 1
#define GREEN 9

#define MS(x) chrono::milliseconds(x)

using namespace std; // we will be using std::chrono
using namespace rtos; // we will be using rtos::ThisThread

// Declaring the Thread objects
Thread led_red_thread;
Thread led_green_thread;

// function to be attached to led_red_thread
void led_red_function() {
  for (;;) {
    // delay while red fades out and green fades in
    ThisThread::sleep_for(MS(512));
    // Fade red out
    for(int i = 255; i >= 0; i--) {
      analogWrite(RED, 255 - i);
      ThisThread::sleep_for(MS(1));
    }
    // delay while green fades out and red fades in
    ThisThread::sleep_for(MS(512));
    // Fade red back in
    for(int i = 05; i < 255; i++) {
      analogWrite(RED, 255 - i);
      ThisThread::sleep_for(MS(1));
    }
  }
}

// function to be attached to led_green_thread
void led_green_function() {
  for (;;) {
    // delay while red fades out
    ThisThread::sleep_for(MS(256));
    // fade green in 
    for(int i = 0; i < 255; i++) {
      analogWrite(GREEN, 255 - i);
      ThisThread::sleep_for(MS(1));
    }
    // delay while green fades out and red fades in
    ThisThread::sleep_for(MS(512));
    // fade green out
    for(int i = 255; i>= 0; i--) {
      analogWrite(GREEN, 255 - i);
      ThisThread::sleep_for(MS(1));
    }
    // delay while red fades in
    ThisThread::sleep_for(MS(256));
  }
}

void setup() {
  pinMode(RED, OUTPUT);
  pinMode(GREEN, OUTPUT);
  led_red_thread.start(led_red_function); // start red thread
  led_green_thread.start(led_green_function); // start green thread
}

void loop() {                  // loop() is executed in its own thread 
   // now left empty
}
