/* threads.ino
 * 
 * This program demonstrates the use of threads with 
 * Arduino MbedOS on an RP2040 microcontroller.
 * It creates two independent threads to print "A" and 
 * "B" to the Serial port at different intervals.
 * Thread t1 prints "A" every 2 seconds.
 * Thread t2 prints "B" every 3 seconds.
 * Note: The loop() function could be used as a third task, 
 * but here no activity was specified for it.
 *
 * The program was tested with Arduino IDE v1.8.19 and 
 * Arduino Mbed OS RP2040 boards v4.1.1 extension.
 */
#include <mbed.h>

using namespace mbed;
using namespace rtos;

using namespace std::chrono_literals;

Thread t1;
Thread t2;

void func1() {
  for (;;) {                        // Repeat forever
    Serial.println("A");            // Print A to the Serial port
    ThisThread::sleep_for(2s);      // Wait for 2 seconds
  }
}

void func2() {
  for (;;) {                        // Repeat forever
    Serial.println("B");            // Print B to the Serial port
    ThisThread::sleep_for(3s);      // Wait for 3 seconds
  }
}

void setup() {
  Serial.begin(115200);             // Start Serial communication
  t1.start(func1);                  // Pass func1 to t1 to start executing it as a independant thread
  t2.start(func2);                  // Pass func2 to t2 to start executing it as an independant thread
}

void loop() {                       // The loop function is executed in its own thread (left empty in this case)
}
